# - * - coding=utf-8 - * -

# Copyright (c) 2015, Sergiusz Bazanski <q3k@q3k.org>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

import requests

from flask import Response, request, redirect, flash, render_template, url_for, abort, g
from flask_login import login_user, login_required, logout_user, current_user

from webapp import app, forms, User, models, cache
import directory

@app.route('/')
def stats():
    return render_template('stats.html')

@app.route('/memberlist')
@login_required
@cache.cached()
def memberlist():
    members = models.Member.get_members(True)
    result = []
    for member in members:
        element = member.get_status()
        if not element['judgement']:
            continue
        result.append(element)

    return render_template('memberlist.html', active_members=result)

@app.route('/profile', methods=['POST', 'GET'])
@login_required
def self_profile():
    member = current_user.get_model()
    if not member:
        abort(404)
    status = member.get_status()
    cn = directory.get_member_fields(g.ldap, member.username, 'cn')['cn']

    return render_template("admin_member.html", member=member, status=status,
                           cn=cn, admin=False)

@app.route("/login", methods=["POST", "GET"])
def login():
    form = forms.LoginForm(request.form)
    if request.method == "POST" and form.validate():
        if requests.post("https://auth.hackerspace.pl/", {
                'login': form.username.data,
                'password': form.password.data}).status_code == 200:
            user = User(form.username.data)
            login_user(user)
            flash('Logged in succesfully')

            if user.is_admin():
                return redirect(request.args.get("next") or url_for("admin.index"))

            return redirect(request.args.get("next") or url_for("self_profile"))
    return render_template("login.html", form=form)


@app.route("/logout")
@login_required
def logout():
    logout_user()
    return redirect(url_for("stats"))


from prometheus_client import multiprocess
from prometheus_client import generate_latest, CollectorRegistry, CONTENT_TYPE_LATEST
@app.route("/varz")
def metrics():
    registry = CollectorRegistry()
    multiprocess.MultiProcessCollector(registry)
    data = generate_latest(registry)
    return Response(data, mimetype=CONTENT_TYPE_LATEST)
